@@ -12,14 +12,14 @@ This collector uses "C<arp>" as the command for the arp utility on your
 system.  If you wish to specify an absolute path, then add an C<arp_command>
 item to your configuration:
 
-device_auth:
-  - tag: sshfreebsd
-    driver: cli
-    platform: FreeBSD
-    only: '192.0.2.1'
-    username: oliver
-    password: letmein
-    arp_command: '/usr/sbin/arp'
+ device_auth:
+   - tag: sshfreebsd
+     driver: cli
+     platform: FreeBSD
+     only: '192.0.2.1'
+     username: oliver
+     password: letmein
+     arp_command: '/usr/sbin/arp'
     
 =cut
 
@@ -39,7 +39,7 @@ use Moo;
 Retrieve ARP entries from device. C<$host> is the hostname or IP address
 of the device. C<$ssh> is a Net::OpenSSH connection to the device.
 
-Returns a list of hashrefs in the format C<{ mac => MACADDR, ip => IPADDR }>.
+Returns a list of hashrefs in the format C<{ mac =E<gt> MACADDR, ip =E<gt> IPADDR }>.
 
 =back
 
