@@ -15,6 +15,7 @@ our @EXPORT_OK = qw/
   get_communities
   snmp_comm_reindex
   get_mibdirs
+  get_mibdirs_shortnames
   decode_and_munge
   sortable_oid
 /;
@@ -155,11 +156,11 @@ Return a list of directories in the `netdisco-mibs` folder.
 sub get_mibdirs {
   my $home = (setting('mibhome') || dir(($ENV{NETDISCO_HOME} || $ENV{HOME}), 'netdisco-mibs'));
   return map { dir($home, $_)->stringify }
-             @{ setting('mibdirs') || _get_mibdirs_content($home) };
+             @{ setting('mibdirs') || get_mibdirs_shortnames() };
 }
 
-sub _get_mibdirs_content {
-  my $home = shift;
+sub get_mibdirs_shortnames {
+  my $home = (setting('mibhome') || dir(($ENV{NETDISCO_HOME} || $ENV{HOME}), 'netdisco-mibs'));
   my @list = map {s|$home/||; $_} grep { m|/[a-z0-9-]+$| } grep {-d} glob("$home/*");
   return \@list;
 }
