@@ -4,7 +4,8 @@ netdisco.util.status
 
 This module provides a Status class which models the return code and message
 of a Python worklet along with convenience methods to set the status. A fresh
-instance of the Status class has an empty message and null (empty string) message.
+instance of the Status class has an empty log message and null (empty string)
+status.
 """
 
 from dataclasses import dataclass
@@ -50,5 +51,9 @@ class StatusManager:
         object.__setattr__(self, 'status', 'info')
         object.__setattr__(self, 'log', msg)
 
+    def reset(self):
+        object.__setattr__(self, 'status', '')
+        object.__setattr__(self, 'log', '')
+
 
 status = StatusManager()
